@@ -2,19 +2,35 @@ package Aspect::Library::Wormhole;
 
 use strict;
 use warnings;
-use Carp;
-use Aspect;
+use Aspect::Modular         ();
+use Aspect::Advice::Before  ();
+use Aspect::Pointcut::And   ();
+use Aspect::Pointcut::Call  ();
+use Aspect::Pointcut::Cflow ();
 
-use base 'Aspect::Modular';
+our $VERSION = '0.93_01';
+our @ISA     = 'Aspect::Modular';
 
 sub get_advice {
-	my ($self, $source, $target) = @_;
-	before { my $c = shift; $c->append_param($c->source->self) }
-		call $target & cflow source => $source;
+	my $self = shift;
+	Aspect::Advice::Before->new(
+		lexical  => $self->lexical,
+		pointcut => Aspect::Pointcut::And->new(
+			Aspect::Pointcut::Call->new( $_[1] ),
+			Aspect::Pointcut::Cflow->new( source => $_[0] ),
+		),
+		code => sub {
+			$_->append_param( $_->source->self );
+		},
+	);
 }
 
 1;
 
+__END__
+
+=pod
+
 =head1 NAME
 
 Aspect::Library::Wormhole - A wormhole between call frames
@@ -24,27 +40,23 @@ Aspect::Library::Wormhole - A wormhole between call frames
   package A;
   sub new { bless {}, shift }
   sub a { B->new->b }
-
+  
   package B;
   sub new { bless {}, shift }
   sub b { C->new->c }
-
+  
   package C;
   sub new { bless {}, shift }
   sub c { ref pop }
-
+  
   package main;
-
+  
   print ref A->new->a; # without aspect, prints C
-
+  
   use Aspect::Library::Wormhole;
   aspect Wormhole => 'A::a', 'C::c';
   print ref A->new->a; # with aspect, prints A
 
-=head1 SUPER
-
-L<Aspect::Modular>
-
 =head1 DESCRIPTION
 
 A reusable aspect for passing objects down a call flow, without adding
@@ -114,12 +126,21 @@ defined on C<Page>, if it is in the call flow of C<Printer::print>:
 
   aspect Wormhole => 'Printer::Print', qr/^Page::/;
 
-=head1 SEE ALSO
+=head1 AUTHORS
 
-See the L<Aspect|::Aspect> pods for a guide to the Aspect module.
+Adam Kennedy E<lt>adamk@cpan.orgE<gt>
 
-You can find an example comparing the OO and AOP solutions in the
-C<examples/> directory of the distribution.
+Marcel GrE<uuml>nauer E<lt>marcel@cpan.orgE<gt>
+
+Ran Eilam E<lt>eilara@cpan.orgE<gt>
+
+=head1 COPYRIGHT
+
+Copyright 2001 by Marcel GrE<uuml>nauer
+
+Some parts copyright 2009 - 2010 Adam Kennedy.
+
+This library is free software; you can redistribute it and/or modify
+it under the same terms as Perl itself.
 
 =cut
-
